<?php

namespace Drupal\spammaster\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\spammaster\SpamMasterLicService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\State\StateInterface;

/**
 * Class controller.
 */
class SpamMasterSettingsForm extends ConfigFormBase {

  /**
   * The SpamMasterLicService service.
   *
   * @var \Drupal\spammaster\SpamMasterLicService
   */
  protected $manualLic;

  /**
   * The state.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * {@inheritdoc}
   */
  public function __construct(SpamMasterLicService $manualLic, StateInterface $state) {
    $this->manualLic = $manualLic;
    $this->state = $state;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('spammaster.lic_service'),
      $container->get('state')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'spammaster_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    // Default settings.
    $config = $this->config('spammaster.settings');
    // Type.
    $response_key = $this->state->get('spammaster.license_status');
    if (empty($response_key)) {
      $response_key = 'INACTIVE';
    }
    // Statuses  Settings.
    $spammaster_protection_total_number = $this->state->get('spammaster.license_protection');
    $spammaster_attached = $this->state->get('spammaster.spam_master_attached');
    if (empty($spammaster_attached) || is_array($spammaster_attached)) {
      $spammaster_attached = 'ERROR detecting email';
    }
    // STATUS VALID.
    if ($response_key == 'VALID') {
      $license_status = 'VALID LICENSE';
      $license_status_colour = 'spam-master-admin-green spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'You are protected against';
      $protection_total_number_text2 = number_format($spammaster_protection_total_number);
      $protection_total_number_text3 = 'Million Threats & Exploits.';
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS EXPIRED.
    if ($response_key == 'EXPIRED') {
      $license_status = 'EXPIRED LICENSE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - EXPIRED OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_1.
    if ($response_key == 'MALFUNCTION_1') {
      $license_status = 'VALID LICENSE';
      $license_status_colour = 'spam-master-admin-yellow spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'You are protected against';
      $protection_total_number_text2 = number_format($spammaster_protection_total_number);
      $protection_total_number_text3 = 'Million Threats & Exploits.';
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_2.
    if ($response_key == 'MALFUNCTION_2') {
      $license_status = 'VALID LICENSE';
      $license_status_colour = 'spam-master-admin-yellow spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'You are protected against';
      $protection_total_number_text2 = number_format($spammaster_protection_total_number);
      $protection_total_number_text3 = 'Million Threats & Exploits.';
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_3.
    if ($response_key == 'MALFUNCTION_3') {
      $license_status = 'MALFUNCTION_3 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_3 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_4.
    if ($response_key == 'MALFUNCTION_4') {
      $license_status = 'MALFUNCTION_4 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_4 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_5.
    if ($response_key == 'MALFUNCTION_5') {
      $license_status = 'MALFUNCTION_5 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_5 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_6.
    if ($response_key == 'MALFUNCTION_6') {
      $license_status = 'MALFUNCTION_6 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_6 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_7.
    if ($response_key == 'MALFUNCTION_7') {
      $license_status = 'MALFUNCTION_7 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_7 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS MALFUNCTION_8.
    if ($response_key == 'MALFUNCTION_8') {
      $license_status = 'MALFUNCTION_8 OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - MALFUNCTION_8 OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS UNSTABLE.
    if ($response_key == 'UNSTABLE') {
      $license_status = 'UNSTABLE OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - Upgrade to PRO';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS HIGH_VOLUME.
    if ($response_key == 'HIGH_VOLUME') {
      $license_status = 'HIGH_VOLUME OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - Upgrade to PRO';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS DISCONNECTED.
    if ($response_key == 'DISCONNECTED') {
      $license_status = 'DISCONNECTED OFFLINE';
      $license_status_colour = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - DISCONNECTED OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }
    // STATUS INACTIVE NO LICENSE SENT YET.
    if ($response_key == 'INACTIVE') {
      $license_status = 'INACTIVE LICENSE';
      $license_status_colour = 'spam-master-admin-yellow spam-master-top-admin-shadow-offline';
      $protection_total_number_text1 = 'WARNING protected against 0 Threats & Exploits - INACTIVE OFFLINE';
      $protection_total_number_text2 = FALSE;
      $protection_total_number_text3 = FALSE;
      $license_attached = $this->t('Your license key is attached to email:&nbsp;<strong>') . $spammaster_attached . $this->t('</strong>&nbsp;');
    }

    // Alert Level Settings.
    $spammaster_alert_level = $this->state->get('spammaster.license_alert_level');
    // ALERT LEVEL, EMPTY.
    if (empty($spammaster_alert_level)) {
      $spammaster_alert_level_label = '';
      $spammaster_alert_level_text = 'Empty data. ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_p_label = 'Empty data. ';
    }
    // ALERT LEVEL, MALFUNCTION_3.
    if ($spammaster_alert_level == 'MALFUNCTION_3') {
      $spammaster_alert_level_label = 'MALFUNCTION_3 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, MALFUNCTION_4.
    if ($spammaster_alert_level == 'MALFUNCTION_4') {
      $spammaster_alert_level_label = 'MALFUNCTION_4 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, MALFUNCTION_5.
    if ($spammaster_alert_level == 'MALFUNCTION_5') {
      $spammaster_alert_level_label = 'MALFUNCTION_5 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, MALFUNCTION_6.
    if ($spammaster_alert_level == 'MALFUNCTION_6') {
      $spammaster_alert_level_label = 'MALFUNCTION_6 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, MALFUNCTION_7.
    if ($spammaster_alert_level == 'MALFUNCTION_7') {
      $spammaster_alert_level_label = 'MALFUNCTION_7 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, MALFUNCTION_8.
    if ($spammaster_alert_level == 'MALFUNCTION_8') {
      $spammaster_alert_level_label = 'MALFUNCTION_8 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, UNSTABLE.
    if ($spammaster_alert_level == 'UNSTABLE') {
      $spammaster_alert_level_label = 'UNSTABLE ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, HIGH_VOLUME.
    if ($spammaster_alert_level == 'HIGH_VOLUME') {
      $spammaster_alert_level_label = 'HIGH_VOLUME ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, DISCONNECTED.
    if ($spammaster_alert_level == 'DISCONNECTED') {
      $spammaster_alert_level_label = 'DISCONNECTED ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> No RBL (real-time blacklist) Server Sync';
      $spammaster_alert_level_p_label = "";
    }
    // ALERT LEVEL, ALERT_0.
    if ($spammaster_alert_level == 'ALERT_0') {
      $spammaster_alert_level_label = 'Alert 0 ';
      $spammaster_alert_level_color = 'spam-master-admin-green spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> Low level of spam and threats. Your website is mainly being visited by occasional harvester bots.';
      $spammaster_alert_level_p_label = 'percent probability.';
    }
    // ALERT LEVEL, ALERT_1.
    if ($spammaster_alert_level == 'ALERT_1') {
      $spammaster_alert_level_label = 'Alert 1 ';
      $spammaster_alert_level_color = 'spam-master-admin-yellow spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> Low level of spam and threats. Your website is mainly being visited by occasional human spammers and harvester bots.';
      $spammaster_alert_level_p_label = 'percent probability.';
    }
    // ALERT LEVEL, ALERT_2.
    if ($spammaster_alert_level == 'ALERT_2') {
      $spammaster_alert_level_label = 'Alert 2 ';
      $spammaster_alert_level_color = 'spam-master-admin-orangina spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> Medium level of spam and threats. Spam Master is actively fighting constant attempts of spam and threats by machine bots.';
      $spammaster_alert_level_p_label = 'percent probability.';
    }
    // ALERT LEVEL, ALERT_3.
    if ($spammaster_alert_level == 'ALERT_3') {
      $spammaster_alert_level_label = 'Alert 3 ';
      $spammaster_alert_level_color = 'spam-master-admin-red spam-master-top-admin-shadow-offline';
      $spammaster_alert_level_text = '-> WARNING! High level of spam and threats, flood detected. Spam Master is fighting an array of human spammers and bot networks which include exploit attempts.';
      $spammaster_alert_level_p_label = 'percent probability.';
    }
    // Description preparation.
    $license_type = $this->state->get('spammaster.type');
    if ('FULL' === $license_type) {
      $spam_type = 'PRO';
      $license_type = 'PRO -> Connected to Spam Master Business Class Servers.';
      $license_class = 'spam-master-admin-green spam-master-top-admin-shadow-offline';
      $license_type_upgrade = $this->t('Congratulations, you have a PRO connection to our business class servers.');
    }
    else {
      $spam_type = $this->state->get('spammaster.type');
      $license_type = $this->state->get('spammaster.type') . ' -> Connected to Spam Master Free Servers.';
      $license_class = 'spam-master-admin-orangina spam-master-top-admin-shadow-red';
      $license_type_upgrade = $this->t('You can improve your connection to our business class servers with a PRO key. <a href="@spammaster_serverstatus" target="@spammaster_target">Spam Master Service > Servers Status</a>.', [
        '@spammaster_serverstatus' => 'https://www.spammaster.org/rbl-servers-status/',
        '@spammaster_target' => '_blank',
      ]);
    }

    $form['license_header'] = [
      '#type' => 'details',
      '#title' => $this->t('<h3>Spam Master <span class="@class">@type</span> Version: @version</h3>', [
        '@class' => $license_class,
        '@type' => $spam_type,
        '@version' => $this->state->get('spammaster.version'),
      ]),
      '#tree' => TRUE,
      '#open' => TRUE,
    ];

    // Insert license key field.
    $form['license_header']['license_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Insert license key number:'),
      '#default_value' => $config->get('spammaster.license_key'),
      '#description' => $this->t('Insert your license key number.&nbsp;') . $license_attached . $this->t('<a href="@spammaster_url" target="@spammaster_target">Get PRO rbl license for peanuts</a>.', [
        '@spammaster_url' => 'https://www.techgasp.com/downloads/spam-master-license/',
        '@spammaster_target' => '_blank',
      ]),
      '#attributes' => [
        'class' => [
          'spammaster-responsive-49',
        ],
      ],
    ];

    $lic_call = $this->manualLic;
    if ('VALID' !== $response_key) {
      $form['license_header']['submit'] = [
        '#type' => 'submit',
        '#attributes' => [
          'class' => ['button button--danger'],
        ],
        '#value' => $this->t('RE-SYNCHRONIZE CONNECTION') . ' ' . $response_key,
        '#submit' => [
          '::validateForm',
          '::submitForm',
          [$lic_call, 'spamMasterLicManualCreation'],
        ],
      ];
      $form['license_header']['submit']['more'] = [
        '#type' => 'item',
        '#markup' => $this->t('<a href="@spammaster_docs_url" target="@spammaster_docs_target">Help about Statuses</a>.', [
          '@spammaster_docs_url' => 'https://www.spammaster.org/documentation/#status',
          '@spammaster_docs_target' => '_blank',
        ]),
        '#required' => FALSE,
        '#weight' => 999,
      ];
    }
    else {
      $form['license_header']['submit'] = [
        '#type' => 'submit',
        '#attributes' => [
          'class' => ['button button--primary'],
        ],
        '#value' => $this->t('Refresh License'),
        '#submit' => [
          '::validateForm',
          '::submitForm',
          [$lic_call, 'spamMasterLicManualCreation'],
        ],
      ];
    }

    // Insert license table inside tree.
    $form['license_header']['license'] = [
      '#type' => 'table',
      '#responsive' => TRUE,
      '#attached' => [
        'library' => [
          'spammaster/spammaster-styles',
        ],
      ],
    ];
    // Insert addrow license status field.
    $form['license_header']['license']['addrow']['license_type'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Your licence type:'),
      '#description' => $this->t('<strong><span class="@lic_class">@lic_type</span></strong> @lic_upgrade', [
        '@lic_class' => $license_class,
        '@lic_type' => $license_type,
        '@lic_upgrade' => $license_type_upgrade,
      ]),
    ];
    $form['license_header']['license']['addrow']['license_status'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Your licence status:'),
      '#description' => $this->t('<strong><span class="@lic_colour">@lic_status</span></strong>. Your license status should always be <strong><span class="spam-master-top-admin-shadow-green">VALID</span></strong>. <a href="@spammaster_url" target="@spammaster_target">About Statuses</a>.', [
        '@lic_colour' => $license_status_colour,
        '@lic_status' => $license_status,
        '@spammaster_url' => 'https://www.spammaster.org/documentation/#status',
        '@spammaster_target' => '_blank',
      ]),
    ];
    // Insert addrow protection field.
    $form['license_header']['license']['addrow1']['license_db_hash'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Your database protection hash:'),
      '#description' => $this->t('<strong><span class="@hash_colour">@hash</span></strong> -> Ensures protection using unique license key and database hash.', [
        '@hash_colour' => 'spam-master-top-admin-shadow-green',
        '@hash' => $this->state->get('spammaster.spam_master_db_protection_hash'),
      ]),
    ];
    // Insert addrow alert level field.
    $form['license_header']['license']['addrow1']['license_alert_level'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Your alert level:'),
      '#description' => $this->t('<strong><span class="@alert_colour">@alert_label</span></strong> @alert_text <a href="@spammaster_url" target="@spammaster_target">About Alert Levels</a>.', [
        '@alert_colour' => $spammaster_alert_level_color,
        '@alert_label' => $spammaster_alert_level_label,
        '@alert_text' => $spammaster_alert_level_text,
        '@spammaster_url' => 'https://www.spammaster.org/documentation/#alert',
        '@spammaster_target' => '_blank',
      ]),
    ];
    // Insert addrow license status field.
    $form['license_header']['license']['addrow2']['license_protection'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Spam Master servers real-time protection count (Threats & Exploits protection number):'),
      '#description' => $this->t('@protection_total1 <strong><span class="spam-master-top-admin-shadow-green">@protection_total2</span></strong> @protection_total3', [
        '@protection_total1' => $protection_total_number_text1,
        '@protection_total2' => $protection_total_number_text2,
        '@protection_total3' => $protection_total_number_text3,
      ]),
    ];
    // Insert addrow alert level field.
    $form['license_header']['license']['addrow2']['license_probability'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Your spam probability:'),
      '#description' => $this->t('<strong><span class="@spam_prob_colour">@spam_prob</span></strong>@spam_prob_alert', [
        '@spam_prob' => $this->state->get('spammaster.license_probability') . '% ',
        '@spam_prob_colour' => $spammaster_alert_level_color,
        '@spam_prob_alert' => $spammaster_alert_level_p_label,
      ]),
    ];
    // Insert addrow help field.
    $form['license_header']['license']['addrow3']['help'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Support:'),
      '#description' => $this->t('Drop us an <a href="@mailto?subject=@mailsub&body=@mailbody">email</a>.', [
        '@mailto' => 'mailto:info@spammaster.org',
        '@mailsub' => 'Module support',
        '@mailbody' => $config->get('spammaster.license_key') . ' *** WRITE BELOW THIS LINE ***',
      ]),
    ];
    // Insert addrow help field.
    $form['license_header']['license']['addrow3']['documentation'] = [
      '#required' => FALSE,
      '#type' => 'item',
      '#title' => $this->t('Documentation:'),
      '#description' => $this->t('Visit Spam Master <a href="@spammaster_url" target="@spammaster_target">Documentation</a>.', [
        '@spammaster_url' => 'https://www.spammaster.org/documentation/',
        '@spammaster_target' => '_blank',
      ]),
    ];

    return parent::buildForm($form, $form_state);

  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (empty($form_state->getValue('license_header')['license_key'])) {
      $form_state->setErrorByName('license_header', $this->t('License key can not be empty.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('spammaster.settings');
    $config->set('spammaster.license_key', $form_state->getValue('license_header')['license_key']);
    $config->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'spammaster.settings',
    ];
  }

}
